//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/List/InstrumentsQListModel.h
//! @brief     Defines class InstrumentsQListModel.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_LIST_INSTRUMENTSQLISTMODEL_H
#define BORNAGAIN_GUI_VIEW_LIST_INSTRUMENTSQLISTMODEL_H

#include <QAbstractListModel>

class InstrumentItem;

//! List of instruments, for use in InstrumentsQListView.

class InstrumentsQListModel : public QAbstractListModel {
    Q_OBJECT
public:
    InstrumentsQListModel();

    int rowCount(const QModelIndex& parent = QModelIndex()) const override;

    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;

    InstrumentItem* instrumentItemForIndex(const QModelIndex& index) const;

    QModelIndex addNewGISASInstrument();
    QModelIndex addNewOffspecInstrument();
    QModelIndex addNewSpecularInstrument();
    QModelIndex addNewDepthprobeInstrument();

    void removeInstrument(const QModelIndex& index);

    QModelIndex copyInstrument(const QModelIndex& source);
    QModelIndex copyInstrument(const InstrumentItem* source);

private:
    template <class Instrument> QModelIndex addNewInstrument();
    void onInstrumentNameChanged(const InstrumentItem* instrument);
};

#endif // BORNAGAIN_GUI_VIEW_LIST_INSTRUMENTSQLISTMODEL_H
